@@ -1,11 +1,11 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * Copyright (C) 2009 Canonical Services Ltd (www.canonical.com)
+ * Copyright (C) 2009-2012 Canonical Ltd.
  *
  * Authors: Rodrigo Moya <rodrigo.moya@canonical.com>
  *
  * This library is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU Lesser General Public
+ * modify it under the terms of version 3 of the GNU Lesser General Public
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
@@ -19,7 +19,7 @@
  * Boston, MA 02110-1301, USA.
  */
 
-#include <libubuntuone/u1-music-store.h>
+#include <libubuntuoneui/u1-music-store.h>
 
 static void
 preview_mp3_cb (U1MusicStore *music_store, const gchar *url, const gchar *title, gpointer user_data)
@@ -55,7 +55,7 @@ main (int argc, char *argv[])
 	GtkWidget *window, *music_store;
 
 	gtk_init (&argc, &argv);
-	g_thread_init (NULL);
+	g_type_init ();
 
 	/* Create the main window */
 	window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
